@@ -58,4 +58,4 @@ def _init_logging(log_name, output_dir=_LOGGING_OUTPUT_DIR, level='DEBUG'):
 
 
 def init_bootstrap_log():
-    return _init_logging('bootstrap.log')
+    return _init_logging('aos-provisioning.log')
